import pygrib
import xarray as xr

def load_data(file_path):
    """
    Load data from a GRIB or NetCDF4 file.
    
    Args:
        file_path (str): Path to the data file.
    
    Returns:
        numpy.ndarray: Loaded data as a numpy array.
    """
    if file_path.endswith(".grib"):
        with pygrib.open(file_path) as grbs:
            data = grbs.read_values()
    elif file_path.endswith(".nc"):
        ds = xr.open_dataset(file_path)
        data = ds.to_array().values
        ds.close()
    else:
        raise ValueError("Unsupported file format. Only GRIB and NetCDF4 are supported.")
    
    return data


from setuptools import setup, find_packages

setup(
    name='nwpeval',
    version='1.4.0',
    description='A package for computing metrics for NWP model evaluation',
    author='Debasish Mahapatra',
    author_email='debasish.atmos@gmail.com | debasish.mahapatra@ugent.be',
    packages=find_packages(),
    install_requires=[
        'numpy',
        'pygrib',
        'xarray',
        'scipy',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Operating System :: OS Independent',
    ],
)